# Annotation

Annotation commands are used to create, position, and modify viewport annotations.

## Create annotations

```{eval-rst}
.. automethod:: abaqus.Annotation.AnimationUserData.AnimationUserData.Arrow
```

```{eval-rst}
.. automethod:: abaqus.Annotation.AnimationUserData.AnimationUserData.Text
```

```{eval-rst}
.. automethod:: abaqus.Annotation.AnimationUserData.AnimationUserData.XYData

```

## Other Classes

```{eval-rst}

.. toggle::

    .. autoclass:: abaqus.Annotation.Annotation.Annotation
        :members:
        :special-members: __init__
        :show-inheritance:

        .. autoclasstoc::

    .. autoclass:: abaqus.Annotation.AnnotationsToPlotArray.AnnotationsToPlotArray
        :members:
        :special-members: __init__
        :show-inheritance:

        .. autoclasstoc::

    .. autoclass:: abaqus.Annotation.AnnotationViewport.AnnotationViewport
        :members:
        :special-members: __init__
        :show-inheritance:

        .. autoclasstoc::

    .. autoclass:: abaqus.Annotation.Arrow.Arrow
        :members:
        :special-members: __init__
        :show-inheritance:

        .. autoclasstoc::

    .. autoclass:: abaqus.Annotation.Text.Text
        :members:
        :special-members: __init__
```
